[Libreoffice-commits] .: 10 commits - configmgr/source desktop/scripts svx/source

Jan Holesovsky kendy at kemper.freedesktop.org
Wed Oct 13 05:41:42 PDT 2010


 configmgr/source/configurationprovider.cxx |   10 ++++++----
 desktop/scripts/soffice.sh                 |    2 +-
 desktop/scripts/unopkg.sh                  |    2 +-
 svx/source/dialog/sendreportunx.cxx        |    2 +-
 svx/source/gengal/gengal.sh                |    6 +++---
 5 files changed, 12 insertions(+), 10 deletions(-)

New commits:
commit 1ddbd702ae05d51e391a312552778be808fde8da
Merge: 11ecb2b... 86423ce...
Author: Jan Holesovsky <kendy at suse.cz>
Date:   Wed Oct 13 14:38:43 2010 +0200

    Merge branch 'master' of ssh://git.freedesktop.org/git/libreoffice/libs-core

commit 11ecb2ba487e9ff85ee61d01808f0a33dc025e1f
Merge: 80df122... c84cd16...
Author: Jan Holesovsky <kendy at suse.cz>
Date:   Wed Oct 13 11:30:59 2010 +0200

    Merge commit 'ooo/OOO330_m10'

commit c84cd1634ee6db999dae05321c228162638d2a81
Merge: 5606219... cf63a5d...
Author: obo <obo at openoffice.org>
Date:   Fri Oct 8 08:45:29 2010 +0200

    CWS-TOOLING: integrate CWS hb22

commit 5606219b345ef8e16f0176f5dde002d8a81da1a1
Merge: ccbb3ff... c9b1d54...
Author: obo <obo at openoffice.org>
Date:   Fri Oct 8 08:19:25 2010 +0200

    CWS-TOOLING: integrate CWS sw33bf10

commit ccbb3ffa0a23579332ce68dec4dbfaa4e145d2fd
Merge: 4ad5d2f... 855fbe2...
Author: obo <obo at openoffice.org>
Date:   Fri Oct 8 08:07:42 2010 +0200

    CWS-TOOLING: integrate CWS fwk159

commit c9b1d54d58d315d26e7461e25d4498905180986c
Author: sb <sb at openoffice.org>
Date:   Wed Sep 29 12:24:07 2010 +0200

    sw33bf10: #i114793# missing rename crash_report.bin -> crashrep

diff --git a/svx/source/dialog/sendreportunx.cxx b/svx/source/dialog/sendreportunx.cxx
index ccd23ae..657399c 100644
--- a/svx/source/dialog/sendreportunx.cxx
+++ b/svx/source/dialog/sendreportunx.cxx
@@ -243,7 +243,7 @@ namespace svx{
             int ret = -1;
             rtl::OUString path1(
                 RTL_CONSTASCII_USTRINGPARAM(
-                    "$BRAND_BASE_DIR/program/crash_report.bin"));
+                    "$BRAND_BASE_DIR/program/crashrep"));
             rtl::Bootstrap::expandMacros(path1);
             rtl::OString path2;
             if ((osl::FileBase::getSystemPathFromFileURL(path1, path1) ==
commit cf63a5d9ec565a3c521c29c346faf56fb3ae2f20
Merge: 3c13c88... d9a1bd0...
Author: Henning Brinkmann <hbrinkm at openoffice.org>
Date:   Mon Sep 20 17:13:53 2010 +0200

    merged OOO330_m8

commit 3c13c882067ebe400937efd0bd59a502b3440bd8
Merge: b47d587... 9f99b1d...
Author: Henning Brinkmann <hbrinkm at openoffice.org>
Date:   Fri Sep 10 17:42:43 2010 +0200

    merged changes by sb

commit 9f99b1dcfe826a7a79a11b3bd83871e3b4231b65
Author: sb <sb at openoffice.org>
Date:   Thu Sep 9 10:48:03 2010 +0200

    hb22: #b6982587# treat null LD_LIBRARY_PATH like unset one

diff --git a/desktop/scripts/soffice.sh b/desktop/scripts/soffice.sh
index e2031c2..30e0f7d 100644
--- a/desktop/scripts/soffice.sh
+++ b/desktop/scripts/soffice.sh
@@ -96,7 +96,7 @@ if [ -x "$sd_prog/../basis-link/ure-link/bin/javaldx" ] ; then
     my_path=`"$sd_prog/../basis-link/ure-link/bin/javaldx" $BOOTSTRAPVARS \
         "-env:INIFILENAME=vnd.sun.star.pathname:$sd_prog/redirectrc"`
     if [ -n "$my_path" ] ; then
-        LD_LIBRARY_PATH=$my_path${LD_LIBRARY_PATH+:$LD_LIBRARY_PATH}
+        LD_LIBRARY_PATH=$my_path${LD_LIBRARY_PATH:+:$LD_LIBRARY_PATH}
         export LD_LIBRARY_PATH
     fi
 fi
diff --git a/desktop/scripts/unopkg.sh b/desktop/scripts/unopkg.sh
index 5a8ee26..3f06444 100644
--- a/desktop/scripts/unopkg.sh
+++ b/desktop/scripts/unopkg.sh
@@ -57,7 +57,7 @@ if [ -x "$sd_prog/../basis-link/ure-link/bin/javaldx" ] ; then
     my_path=`"$sd_prog/../basis-link/ure-link/bin/javaldx" $BOOTSTRAPVARS \
         "-env:INIFILENAME=vnd.sun.star.pathname:$sd_prog/redirectrc"`
     if [ -n "$my_path" ] ; then
-        LD_LIBRARY_PATH=$my_path${LD_LIBRARY_PATH+:$LD_LIBRARY_PATH}
+        LD_LIBRARY_PATH=$my_path${LD_LIBRARY_PATH:+:$LD_LIBRARY_PATH}
         export LD_LIBRARY_PATH
     fi
 fi
diff --git a/svx/source/gengal/gengal.sh b/svx/source/gengal/gengal.sh
index 38e680e..2fccd22 100644
--- a/svx/source/gengal/gengal.sh
+++ b/svx/source/gengal/gengal.sh
@@ -67,17 +67,17 @@ case $sd_platform in
     ;;
 
   Darwin)
-    DYLD_LIBRARY_PATH=${sd_prog}${DYLD_LIBRARY_PATH+:${DYLD_LIBRARY_PATH}}
+    DYLD_LIBRARY_PATH=${sd_prog}${DYLD_LIBRARY_PATH:+:${DYLD_LIBRARY_PATH}}
     export DYLD_LIBRARY_PATH
     ;;
 
   HP-UX)
-    SHLIB_PATH=${sd_prog}:/usr/openwin/lib${SHLIB_PATH+:${SHLIB_PATH}}
+    SHLIB_PATH=${sd_prog}:/usr/openwin/lib${SHLIB_PATH:+:${SHLIB_PATH}}
     export SHLIB_PATH
     ;;
 
   *)
-    LD_LIBRARY_PATH=${sd_prog}${LD_LIBRARY_PATH+:${LD_LIBRARY_PATH}}
+    LD_LIBRARY_PATH=${sd_prog}${LD_LIBRARY_PATH:+:${LD_LIBRARY_PATH}}
     export LD_LIBRARY_PATH
     ;;
 esac
commit 855fbe2dbeeecc713a22abd4ec0ddb6abbe54f02
Author: sb <sb at openoffice.org>
Date:   Mon Jun 21 17:41:23 2010 +0200

    sb126: #i111970# accept and ignore EnableAsync
    (transplanted from 0c119e327cea31601db9932cf3f85bbab9ee06f5)

diff --git a/configmgr/source/configurationprovider.cxx b/configmgr/source/configurationprovider.cxx
index a89540a..78d71e7 100644
--- a/configmgr/source/configurationprovider.cxx
+++ b/configmgr/source/configurationprovider.cxx
@@ -241,7 +241,7 @@ Service::createInstanceWithArguments(
     if (nodepath.getLength() == 0) {
         badNodePath();
     }
-    // For backwards compatibility, allow a notepath that misses the leading
+    // For backwards compatibility, allow a nodepath that misses the leading
     // slash:
     if (nodepath[0] != '/') {
         nodepath = rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("/")) + nodepath;
@@ -456,7 +456,8 @@ Factory::createInstanceWithArgumentsAndContext(
                             " arguments")),
                     0);
             }
             // For backwards compatibility, allow "Locale" in any case:
             if (name.equalsIgnoreAsciiCaseAsciiL(
                     RTL_CONSTASCII_STRINGPARAM("locale")))
             {
@@ -471,8 +472,9 @@ Factory::createInstanceWithArgumentsAndContext(
                                 " one, non-empty, string Locale argument")),
                         0);
                 }
-            } else {
-                //TODO
+            } else if (!name.equalsIgnoreAsciiCaseAsciiL(
+                           RTL_CONSTASCII_STRINGPARAM("enableasync")))
+            {
                 throw css::uno::Exception(
                     rtl::OUString(
                         RTL_CONSTASCII_USTRINGPARAM(
@@ -456,7 +456,8 @@ Factory::createInstanceWithArgumentsAndContext(
                     0);
             }
-            // For backwards compatibility, allow "Locale" in any case:
+            // For backwards compatibility, allow "Locale" and (ignored)
+            // "EnableAsync" in any case:
             if (name.equalsIgnoreAsciiCaseAsciiL(
                     RTL_CONSTASCII_STRINGPARAM("locale")))


More information about the Libreoffice-commits mailing list